@@ -1,11 +1,14 @@
 from cqrs.dispatcher.event import EventDispatcher
-from cqrs.dispatcher.models import RequestDispatchResult
+from cqrs.dispatcher.models import RequestDispatchResult, SagaDispatchResult
 from cqrs.dispatcher.request import RequestDispatcher
+from cqrs.dispatcher.saga import SagaDispatcher
 from cqrs.dispatcher.streaming import StreamingRequestDispatcher
 
 __all__ = (
     "RequestDispatchResult",
+    "SagaDispatchResult",
     "RequestDispatcher",
+    "SagaDispatcher",
     "StreamingRequestDispatcher",
     "EventDispatcher",
 )
